Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(121)

Unified Diff: chromeos/dbus/shill_manager_client.cc

Issue 10915106: Renaming instances of "flimflam" with "shill", now that we're only (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Upload after merge Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chromeos/dbus/shill_manager_client.h ('k') | chromeos/dbus/shill_manager_client_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/dbus/shill_manager_client.cc
diff --git a/chromeos/dbus/flimflam_manager_client.cc b/chromeos/dbus/shill_manager_client.cc
similarity index 85%
rename from chromeos/dbus/flimflam_manager_client.cc
rename to chromeos/dbus/shill_manager_client.cc
index 034d01e1256d8bb13c9a8e098d41db42d1fb3612..96d0e3e4969b48fb96d002df5cc677e81fda17b4 100644
--- a/chromeos/dbus/flimflam_manager_client.cc
+++ b/chromeos/dbus/shill_manager_client.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "chromeos/dbus/flimflam_manager_client.h"
+#include "chromeos/dbus/shill_manager_client.h"
#include "base/bind.h"
#include "base/chromeos/chromeos_version.h"
@@ -40,16 +40,16 @@ void AppendServicePropertiesDictionary(
dbus::MessageWriter entry_writer(NULL);
array_writer.OpenDictEntry(&entry_writer);
entry_writer.AppendString(it.key());
- FlimflamClientHelper::AppendValueDataAsVariant(&entry_writer, it.value());
+ ShillClientHelper::AppendValueDataAsVariant(&entry_writer, it.value());
array_writer.CloseContainer(&entry_writer);
}
writer->CloseContainer(&array_writer);
}
-// The FlimflamManagerClient implementation.
-class FlimflamManagerClientImpl : public FlimflamManagerClient {
+// The ShillManagerClient implementation.
+class ShillManagerClientImpl : public ShillManagerClient {
public:
- explicit FlimflamManagerClientImpl(dbus::Bus* bus)
+ explicit ShillManagerClientImpl(dbus::Bus* bus)
: proxy_(bus->GetObjectProxy(
flimflam::kFlimflamServiceName,
dbus::ObjectPath(flimflam::kFlimflamServicePath))),
@@ -57,7 +57,7 @@ class FlimflamManagerClientImpl : public FlimflamManagerClient {
helper_.MonitorPropertyChanged(flimflam::kFlimflamManagerInterface);
}
- // FlimflamManagerClient overrides:
+ // ShillManagerClient overrides:
virtual void SetPropertyChangedHandler(
const PropertyChangedHandler& handler) OVERRIDE {
helper_.SetPropertyChangedHandler(handler);
@@ -86,7 +86,7 @@ class FlimflamManagerClientImpl : public FlimflamManagerClient {
flimflam::kSetPropertyFunction);
dbus::MessageWriter writer(&method_call);
writer.AppendString(name);
- FlimflamClientHelper::AppendValueDataAsVariant(&writer, value);
+ ShillClientHelper::AppendValueDataAsVariant(&writer, value);
helper_.CallVoidMethod(&method_call, callback);
}
@@ -142,16 +142,16 @@ class FlimflamManagerClientImpl : public FlimflamManagerClient {
private:
dbus::ObjectProxy* proxy_;
- FlimflamClientHelper helper_;
+ ShillClientHelper helper_;
- DISALLOW_COPY_AND_ASSIGN(FlimflamManagerClientImpl);
+ DISALLOW_COPY_AND_ASSIGN(ShillManagerClientImpl);
};
// A stub implementation of FlimflamManagerClient.
// Implemented: Stub cellular DeviceList entry for SMS testing.
-class FlimflamManagerClientStubImpl : public FlimflamManagerClient {
+class ShillManagerClientStubImpl : public ShillManagerClient {
public:
- FlimflamManagerClientStubImpl() : weak_ptr_factory_(this) {
+ ShillManagerClientStubImpl() : weak_ptr_factory_(this) {
base::ListValue* device_list = new base::ListValue;
// Note: names match Device stub map.
const char kStubCellular1[] = "stub_cellular1";
@@ -161,30 +161,30 @@ class FlimflamManagerClientStubImpl : public FlimflamManagerClient {
stub_properties_.Set(flimflam::kDevicesProperty, device_list);
}
- virtual ~FlimflamManagerClientStubImpl() {}
+ virtual ~ShillManagerClientStubImpl() {}
- // FlimflamManagerClient override.
+ // ShillManagerClient override.
virtual void SetPropertyChangedHandler(
const PropertyChangedHandler& handler) OVERRIDE {}
- // FlimflamManagerClient override.
+ // ShillManagerClient override.
virtual void ResetPropertyChangedHandler() OVERRIDE {}
- // FlimflamManagerClient override.
+ // ShillManagerClient override.
virtual void GetProperties(const DictionaryValueCallback& callback) OVERRIDE {
MessageLoop::current()->PostTask(
FROM_HERE, base::Bind(
- &FlimflamManagerClientStubImpl::PassStubProperties,
+ &ShillManagerClientStubImpl::PassStubProperties,
weak_ptr_factory_.GetWeakPtr(),
callback));
}
- // FlimflamManagerClient override.
+ // ShillManagerClient override.
virtual base::DictionaryValue* CallGetPropertiesAndBlock() OVERRIDE {
return new base::DictionaryValue;
}
- // FlimflamManagerClient override.
+ // ShillManagerClient override.
virtual void SetProperty(const std::string& name,
const base::Value& value,
const VoidDBusMethodCallback& callback) OVERRIDE {
@@ -194,7 +194,7 @@ class FlimflamManagerClientStubImpl : public FlimflamManagerClient {
DBUS_METHOD_CALL_SUCCESS));
}
- // FlimflamManagerClient override.
+ // ShillManagerClient override.
virtual void RequestScan(const std::string& type,
const VoidDBusMethodCallback& callback) OVERRIDE {
MessageLoop::current()->PostTask(FROM_HERE,
@@ -202,7 +202,7 @@ class FlimflamManagerClientStubImpl : public FlimflamManagerClient {
DBUS_METHOD_CALL_SUCCESS));
}
- // FlimflamManagerClient override.
+ // ShillManagerClient override.
virtual void EnableTechnology(
const std::string& type,
const VoidDBusMethodCallback& callback) OVERRIDE {
@@ -211,7 +211,7 @@ class FlimflamManagerClientStubImpl : public FlimflamManagerClient {
DBUS_METHOD_CALL_SUCCESS));
}
- // FlimflamManagerClient override.
+ // ShillManagerClient override.
virtual void DisableTechnology(
const std::string& type,
const VoidDBusMethodCallback& callback) OVERRIDE {
@@ -220,7 +220,7 @@ class FlimflamManagerClientStubImpl : public FlimflamManagerClient {
DBUS_METHOD_CALL_SUCCESS));
}
- // FlimflamManagerClient override.
+ // ShillManagerClient override.
virtual void ConfigureService(
const base::DictionaryValue& properties,
const VoidDBusMethodCallback& callback) OVERRIDE {
@@ -229,7 +229,7 @@ class FlimflamManagerClientStubImpl : public FlimflamManagerClient {
DBUS_METHOD_CALL_SUCCESS));
}
- // FlimflamManagerClient override.
+ // ShillManagerClient override.
virtual void GetService(
const base::DictionaryValue& properties,
const ObjectPathDBusMethodCallback& callback) OVERRIDE {
@@ -248,25 +248,25 @@ class FlimflamManagerClientStubImpl : public FlimflamManagerClient {
// Note: This should remain the last member so it'll be destroyed and
// invalidate its weak pointers before any other members are destroyed.
- base::WeakPtrFactory<FlimflamManagerClientStubImpl> weak_ptr_factory_;
+ base::WeakPtrFactory<ShillManagerClientStubImpl> weak_ptr_factory_;
- DISALLOW_COPY_AND_ASSIGN(FlimflamManagerClientStubImpl);
+ DISALLOW_COPY_AND_ASSIGN(ShillManagerClientStubImpl);
};
} // namespace
-FlimflamManagerClient::FlimflamManagerClient() {}
+ShillManagerClient::ShillManagerClient() {}
-FlimflamManagerClient::~FlimflamManagerClient() {}
+ShillManagerClient::~ShillManagerClient() {}
// static
-FlimflamManagerClient* FlimflamManagerClient::Create(
+ShillManagerClient* ShillManagerClient::Create(
DBusClientImplementationType type,
dbus::Bus* bus) {
if (type == REAL_DBUS_CLIENT_IMPLEMENTATION)
- return new FlimflamManagerClientImpl(bus);
+ return new ShillManagerClientImpl(bus);
DCHECK_EQ(STUB_DBUS_CLIENT_IMPLEMENTATION, type);
- return new FlimflamManagerClientStubImpl();
+ return new ShillManagerClientStubImpl();
}
} // namespace chromeos
« no previous file with comments | « chromeos/dbus/shill_manager_client.h ('k') | chromeos/dbus/shill_manager_client_unittest.cc » ('j') | no next file with comments »
@@ -142,16 +142,16 @@ class FlimflamManagerClientImpl : public FlimflamManagerClient {
};
-// A stub implementation of FlimflamManagerClient.
+// A stub implementation of ShillManagerClient.
// Implemented: Stub cellular DeviceList entry for SMS testing.

Powered by Google App Engine
This is Rietveld 408576698